@@ -5,16 +5,28 @@ from uuid import UUID
 from pydantic import parse_obj_as
 from requests import HTTPError, Response
 
-from .constants import BROKER_DOCUMENT_UPLOAD_LIMIT
 from .enums import ACHRelationshipStatus
 from alpaca.broker.models import (
     ACHRelationship,
     Account,
-    AccountCreationRequest,
-    AccountUpdateRequest,
-    ActivityType,
     Bank,
     CIPInfo,
+    TradeAccount,
+    TradeAccountConfiguration,
+    TradeDocument,
+    Transfer,
+    Order,
+    BatchJournalResponse,
+    Journal,
+)
+from .requests import (
+    CreateJournalRequest,
+    CreateBatchJournalRequest,
+    CreateReverseBatchJournalRequest,
+    GetJournalsRequest,
+    OrderRequest,
+    CancelOrderResponse,
+    UploadDocumentRequest,
     CreateACHRelationshipRequest,
     CreateACHTransferRequest,
     CreateBankRequest,
@@ -24,97 +36,45 @@ from alpaca.broker.models import (
     GetTradeDocumentsRequest,
     GetTransfersRequest,
     ListAccountsRequest,
-    TradeAccount,
-    TradeAccountConfiguration,
-    TradeDocument,
-    Transfer,
-    UploadDocumentRequest,
-    Order,
-    OrderRequest,
-    CancelOrderResponse,
-    CreateJournalRequest,
-    BatchJournalResponse,
-    CreateBatchJournalRequest,
-    CreateReverseBatchJournalRequest,
-    GetJournalsRequest,
-    Journal,
+    CreateAccountRequest,
+    UpdateAccountRequest,
 )
-from ..common import APIError
-from ..common.constants import ACCOUNT_ACTIVITIES_DEFAULT_PAGE_SIZE
-from ..common.enums import BaseURL, PaginationType
-from ..common.models import (
+from alpaca.common.exceptions import APIError
+from alpaca.common.constants import (
+    ACCOUNT_ACTIVITIES_DEFAULT_PAGE_SIZE,
+    BROKER_DOCUMENT_UPLOAD_LIMIT,
+)
+from alpaca.common.enums import BaseURL, PaginationType
+from alpaca.trading.models import (
+    PortfolioHistory,
+    Position,
+    ClosePositionResponse,
+    Asset,
+    Watchlist,
+    Calendar,
+    Clock,
+)
+from alpaca.trading.models import (
     BaseActivity,
     NonTradeActivity,
     TradeActivity,
+)
+from alpaca.trading.requests import (
     GetPortfolioHistoryRequest,
-    PortfolioHistory,
     ClosePositionRequest,
-    Position,
-    ClosePositionResponse,
-    Calendar,
-    Clock,
     GetCalendarRequest,
     UpdateWatchlistRequest,
-    Watchlist,
     CreateWatchlistRequest,
-    Asset,
     ReplaceOrderRequest,
     GetAssetsRequest,
     GetOrdersRequest,
     GetOrderByIdRequest,
 )
+from alpaca.trading.enums import (
+    ActivityType,
+)
 from ..common.rest import HTTPResult, RESTClient
-
-
-def validate_uuid_id_param(
-    id: Union[UUID, str],
-    var_name: Optional[str] = None,
-) -> UUID:
-    """
-    A small helper function to eliminate duplicate checks of various id parameters to ensure they are
-    valid UUIDs. Upcasts str instances that are valid UUIDs into UUID instances.
-
-    Args:
-        id (Union[UUID, str]): The parameter to be validated
-        var_name (Optional[str]): the name of the parameter you'd like to generate in the error message. Defaults to
-          using `account_id` due to it being the most commonly needed case
-
-    Returns:
-        UUID: The valid UUID instance
-    """
-
-    if var_name is None:
-        var_name = "account_id"
-
-    # should raise ValueError
-    if type(id) == str:
-        id = UUID(id)
-    elif type(id) != UUID:
-        raise ValueError(f"{var_name} must be a UUID or a UUID str")
-
-    return id
-
-
-def validate_symbol_or_asset_id(
-    symbol_or_asset_id: Union[UUID, str]
-) -> Union[UUID, str]:
-    """
-    A helper function to eliminate duplicate checks of symbols or asset ids.
-
-    If the argument given is a string, assumed to be a symbol name. If a UUID object, assumed to be an asset id.
-    ValueError if neither type.
-
-    Args:
-        symbol_or_asset_id: String representing a symbol name or a UUID representing an asset id.
-
-    Returns:
-        String if symbol, UUID if asset id.
-    """
-    if isinstance(symbol_or_asset_id, (UUID, str)):
-        return symbol_or_asset_id
-    raise ValueError(
-        f"symbol_or_asset_id must be a UUID of an asset id or a string of a symbol."
-    )
+from alpaca.common.utils import validate_uuid_id_param, validate_symbol_or_asset_id
 
 
 class BrokerClient(RESTClient):
@@ -184,13 +144,13 @@ class BrokerClient(RESTClient):
 
     def create_account(
         self,
-        account_data: AccountCreationRequest,
+        account_data: CreateAccountRequest,
     ) -> Account:
         """
         Create an account.
 
         Args:
-            account_data (AccountCreationRequest): The data representing the Account you wish to create
+            account_data (CreateAccountRequest): The data representing the Account you wish to create
 
         Returns:
             Account: The newly created Account instance as returned from the API. Should now have id
@@ -227,7 +187,7 @@ class BrokerClient(RESTClient):
     def update_account(
         self,
         account_id: Union[UUID, str],
-        update_data: AccountUpdateRequest,
+        update_data: UpdateAccountRequest,
     ) -> Account:
         """
         Updates data for an account with an id of `account_id`. Note that not all data for an account is modifiable
@@ -239,7 +199,7 @@ class BrokerClient(RESTClient):
         Args:
             account_id (Union[UUID, str]): The id for the account you with to update. str uuid values will be upcast
             into UUID instances
-            update_data (AccountUpdateRequest): The data you wish to update this account to
+            update_data (UpdateAccountRequest): The data you wish to update this account to
 
         Returns:
             Account: Returns an Account instance with the updated data as returned from the api
@@ -1019,7 +979,7 @@ class BrokerClient(RESTClient):
             close_options: The various close position request parameters.
 
         Returns:
-            Order: The order that was placed to close the position.
+            alpaca.broker.models.Order: The order that was placed to close the position.
         """
         account_id = validate_uuid_id_param(account_id)
         symbol_or_asset_id = validate_symbol_or_asset_id(symbol_or_asset_id)
@@ -1420,10 +1380,10 @@ class BrokerClient(RESTClient):
 
         Args:
             account_id (Union[UUID, str]): The account the order will be created for.
-            order_data (OrderRequest): The request data for creating a new order.
+            order_data (alpaca.broker.requests.OrderRequest): The request data for creating a new order.
 
         Returns:
-            Order: The resulting submitted order.
+            alpaca.broker.models.OrderOrder: The resulting submitted order.
         """
 
         account_id = validate_uuid_id_param(account_id, "account_id")
@@ -1445,7 +1405,7 @@ class BrokerClient(RESTClient):
             filter (Optional[GetOrdersRequest]): The parameters to filter the orders with.
 
         Returns:
-            List[Order]: The queried orders.
+            List[alpaca.broker.models.Order]: The queried orders.
         """
         account_id = validate_uuid_id_param(account_id, "account_id")
 
@@ -1474,7 +1434,7 @@ class BrokerClient(RESTClient):
             filter (Optional[GetOrderByIdRequest]): The parameters for the query.
 
         Returns:
-            Order: The order that was queried.
+            alpaca.broker.models.Order: The order that was queried.
         """
         account_id = validate_uuid_id_param(account_id, "account_id")
         order_id = validate_uuid_id_param(order_id, "order_id")
@@ -1497,7 +1457,7 @@ class BrokerClient(RESTClient):
             client_id (str): The client order identifier for the order.
 
         Returns:
-            Order: The queried order.
+            alpaca.broker.models.Order: The queried order.
         """
         account_id = validate_uuid_id_param(account_id, "account_id")
 
@@ -1520,7 +1480,7 @@ class BrokerClient(RESTClient):
             order_data (Optional[ReplaceOrderRequest]): The parameters we wish to update.
 
         Returns:
-            Order: The updated order.
+            alpaca.broker.models.Order: The updated order.
         """
         account_id = validate_uuid_id_param(account_id, "account_id")
         order_id = validate_uuid_id_param(order_id, "order_id")
